import { Component, Input, OnInit } from '@angular/core';
import { MqttclientService } from '../mqttclient.service'

@Component({
  selector: 'heatingcontroller',
  template: `
  <div [ngStyle]="{ 'text-align': 'center', 'background-color':'lightgrey', 'border-radius':'10px', 
  'width': '150px', 'padding':'5px', 'margin': '5px',
  'font-family': 'sans-serif' }">
  {{label}}<br/>
  <button mat-mini-fab color="primary" (click)="clickOff()" [ngStyle]="{'font-size':'100%'}">off</button>
  <button mat-mini-fab color="primary" (click)="clickOn()" [ngStyle]="{'font-size':'100%'}">on</button>
  <button mat-mini-fab color="primary" (click)="clickForceOn()" [ngStyle]="{'font-size':'100%'}">forceOn</button>
  <br/>
  <!-- <input type="text" [value]="currentTemperature"></input> -->
  <br/>
  <!-- <input type="text" [value]="presetTemperature"></input> -->
  </div>
  `
  
})
export class HeatingControllerComponent implements OnInit {
  @Input() topicPre : string = 'invalid'
  commandTopic : string = 'invalid'
  presetTopic : string = 'invalid'
  feedbackPresetTopic : string = 'invalid'
  temperatureTopic : string = 'invalid'
  feedbackTemperatureTopic : string = 'invalid'
  @Input() label : string = 'invalid'

  currentTemperature : string
  presetTemperature : string
  
  constructor(private mqttclientService : MqttclientService) { }
  
  ngOnInit() {
    this.commandTopic = this.topicPre + '/command'
    this.presetTopic = this.topicPre + '/presetTemperature'
    this.feedbackPresetTopic = this.topicPre + '/presetTemperature/feedback'
    this.temperatureTopic = this.topicPre + '/temperature'
    this.feedbackTemperatureTopic = this.topicPre + '/temperature/feedback'

    this.mqttclientService.register(this.feedbackTemperatureTopic, (message: string) => {
      this.currentTemperature = message
    })
    this.mqttclientService.register(this.feedbackPresetTopic, (message: string) => {
      this.presetTemperature = message
    })
  }
  
  clickOn() {
    console.log(`click on for ${this.commandTopic}`)
    this.mqttclientService.publish(this.commandTopic, "ON")
  }
  
  clickForceOn() {
    console.log(`click absent for ${this.commandTopic}`)
    this.mqttclientService.publish(this.commandTopic, "FORCE_ON")
  }
  
  clickOff() {
    console.log(`click off for ${this.commandTopic}`)
    this.mqttclientService.publish(this.commandTopic, "OFF")
  }
  
}

